@@ -276,8 +276,10 @@ class PolygonShape(AbstractShape):
         painter.setBrush(brush)
         points = self.transform_points(xMap, yMap)
         if self.ADDITIONNAL_POINTS:
-            shape_points = points[: -self.ADDITIONNAL_POINTS]
-            other_points = points[-self.ADDITIONNAL_POINTS :]
+            # Slice indexing is not supported by PySide6, so we convert the `QPolygonF`
+            # object to a list before converting it back to a `QPolygonF` object:
+            shape_points = QG.QPolygonF(list(points)[: -self.ADDITIONNAL_POINTS])
+            other_points = QG.QPolygonF(list(points)[-self.ADDITIONNAL_POINTS :])
         else:
             shape_points = points
             other_points = []
